==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpgtBinop.h <==
// public final class soot.jimple.parser.node.ACmpgtBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a1043ddd8551a1b6 soot_jimple_parser_node_ACmpgtBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgtBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgtBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpgt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$refs	_jc_soot_jimple_parser_node_ACmpgtBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$object	_jc_soot_jimple_parser_node_ACmpgtBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgtBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtable	_jc_soot_jimple_parser_node_ACmpgtBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtype	_jc_soot_jimple_parser_node_ACmpgtBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$_init$4b9e29138c1f1625(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpgt$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$getCmpgt$cbcd878e35564264(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$setCmpgt$a0ff0b51b94fd6b6(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$getCmpgt$cbcd878e35564264;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$setCmpgt$a0ff0b51b94fd6b6;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpgt$object	*(*getCmpgt$cbcd878e35564264)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpgt$a0ff0b51b94fd6b6)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vmethods	soot_jimple_parser_node_ACmpgtBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpgt$object	*__5fcmpgt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs	soot_jimple_parser_node_ACmpgtBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgtBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgtBinop$object {
	_jc_soot_jimple_parser_node_ACmpgtBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgtBinop$vtype _jc_soot_jimple_parser_node_ACmpgtBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgtBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgtBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgtBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpgtBinop.h <==
// public final class soot.jimple.parser.node.ACmpgtBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a1043ddd8551a1b6 soot_jimple_parser_node_ACmpgtBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgtBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgtBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpgt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$refs	_jc_soot_jimple_parser_node_ACmpgtBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgtBinop$object	_jc_soot_jimple_parser_node_ACmpgtBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgtBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtable	_jc_soot_jimple_parser_node_ACmpgtBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtype	_jc_soot_jimple_parser_node_ACmpgtBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$_init$4b9e29138c1f1625(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpgt$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$getCmpgt$cbcd878e35564264(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgtBinop$method$setCmpgt$a0ff0b51b94fd6b6(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgtBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$getCmpgt$cbcd878e35564264;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$setCmpgt$a0ff0b51b94fd6b6;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgtBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpgt$object	*(*getCmpgt$cbcd878e35564264)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpgt$a0ff0b51b94fd6b6)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *, struct _jc_soot_jimple_parser_node_TCmpgt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgtBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vmethods	soot_jimple_parser_node_ACmpgtBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgtBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpgt$object	*__5fcmpgt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgtBinop$sub_refs	soot_jimple_parser_node_ACmpgtBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgtBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgtBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgtBinop$object {
	_jc_soot_jimple_parser_node_ACmpgtBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgtBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgtBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgtBinop$vtype _jc_soot_jimple_parser_node_ACmpgtBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgtBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgtBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgtBinop_H_ */
